@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_PREF_H_
 #define __GWEATHER_PREF_H_
 
-/* $Id: gweather-pref.h,v 1.7 2003/06/06 15:33:15 dcransto Exp $ */
+/* $Id: gweather-pref.h,v 1.8 2003/07/13 23:17:52 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,8 +26,6 @@ extern void gweather_pref_save (const gchar *path, GWeatherApplet *gw_applet);
 void add_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType type);
 void set_access_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
 
-GtkWidget *
-hig_category_new (GtkWidget *parent, gchar *title, gboolean expand, gboolean fill);
 
 
 G_END_DECLS
